@@ -28,6 +28,7 @@ import shutil
 import subprocess
 import sys
 import time
+import re
 
 OSX_DISTRIBUTION_NAME = "osx"
 WIN32_DISTRIBUTION_NAME = "win32"
@@ -329,7 +330,7 @@ def run_init(args):
     # The client submodule has QML files, so we need to run qmlformat on it,
     # and thus need to supply the Qt path.
     execute_script([f'{format_script} --install {client_hooks_dir}'
-                    f' --qt {args.qt}' if args.qt else ''],
+                    f' --qt {args.qt}'],
                    {"path": client_hooks_dir})
 
     # The daemon submodule has no QML files, so we don't need to run
@@ -363,10 +364,10 @@ def cwd(path):
 def run_install(args):
     # Platforms with special compilation scripts
     if args.distribution == WIN32_DISTRIBUTION_NAME:
-        with cwd('daemon/compat/msvc'):
-            execute_script(
-                ['python winmake.py -iv '
-                 f'-s {args.sdk} -b daemon'])
+        if not args.pywinmake:
+            with cwd('daemon/compat/msvc'):
+                execute_script([f'python winmake.py -iv -s {args.sdk} -b daemon'])
+
         build_windows = 'extras/scripts/build-windows.py'
         execute_script([f'python {build_windows} --init'])
         execute_script([f'python {build_windows} --qt={args.qt}'])
@@ -386,6 +387,8 @@ def run_install(args):
         install_args.append('-u')
     if args.debug:
         install_args.append('-d')
+    if args.asan:
+        install_args.append('-A')
     if args.no_libwrap:
         install_args.append('-W')
     if args.no_webengine:
@@ -416,6 +419,11 @@ def run_install(args):
 
     command = ['extras/scripts/install.sh'] + install_args
 
+    if 'TARBALLS' not in os.environ:
+        print('info: consider setting the TARBALLS environment variable '
+              'to a stable writable location to avoid loosing '
+              'cached tarballs')
+
     if args.distribution == 'guix':
         if args.global_install:
             print('error: global install is not supported when using Guix.')
@@ -425,10 +433,6 @@ def run_install(args):
         if 'TARBALLS' in os.environ:
             share_tarballs_args = ['--preserve=TARBALLS',
                                    f'--share={os.environ["TARBALLS"]}']
-        else:
-            print('info: consider setting the TARBALLS environment variable '
-                  'to a stable writable location to avoid loosing '
-                  'cached tarballs')
         command = ['guix', 'shell', f'--manifest={GUIX_MANIFEST}',
                    '--symlink=/usr/bin/env=bin/env',
                    '--symlink=/etc/ssl/certs=etc/ssl/certs',
@@ -457,6 +461,93 @@ def run_clean():
                     'git submodule foreach git clean -xfd'])
 
 
+def clean_contribs(contribs):
+    """
+    Helper to clean one or more of the libjami contribs.
+
+    Takes a list of contrib names(space separated) to clean, or 'all' to clean all contribs.
+
+    Contribs are assumed to be in the contrib_dir: daemon/contrib
+    Artifacts to remove include:
+    - build directory: <contrib_dir>/<native_dir>/<contrib_name>
+    - build stamp: <contrib_dir>/<native_dir>/.<contrib_name>
+    - tarball: <contrib_dir>/tarballs/<contrib_name>*.tar.*
+    - build artifacts (we don't care about the contents of share):
+        - <contrib_dir>/<abi_triplet>/bin/<contrib_name>
+        - <contrib_dir>/<abi_triplet>/lib/<contrib_name>*
+        - <contrib_dir>/<abi_triplet>/include/<contrib_name>*
+    """
+
+    # Not supported on Windows
+    if platform.system() == 'Windows':
+        print('Cleaning contribs is not supported on Windows. Exiting.')
+        sys.exit(1)
+
+    # Assume we are using the submodule here.
+    contrib_dir = 'daemon/contrib'
+    sub_dirs = os.listdir(contrib_dir)
+
+    # Let's find the abi triplet:
+    # The abi_triplet is 3 parts: <arch>-<vendor>-<sys> and should be the only directory
+    # named like that in the contrib directory. We can use a regex to find it.
+    triplet_pattern = re.compile(r'^[a-zA-Z0-9_]+-[a-zA-Z0-9_]+-[a-zA-Z0-9_]+$')
+    def is_triplet(s):
+        return bool(triplet_pattern.match(s))
+    abi_triplet = ''
+    for sub_dir in sub_dirs:
+        if is_triplet(sub_dir):
+            abi_triplet = sub_dir
+            break
+
+    # If we didn't find the abi triplet, we need to stop.
+    if abi_triplet == '':
+        print('Could not find the abi triplet for the contribs. Exiting.')
+        sys.exit(1)
+
+    # Let's find the native build source directory (native-*)
+    native_dir = ''
+    for sub_dir in sub_dirs:
+        if sub_dir.startswith('native'):
+            native_dir = os.path.join(contrib_dir, sub_dir)
+            break
+
+    # If we didn't find the native build source directory, we need to stop.
+    if native_dir == '':
+        print('Could not find the native build source directory. Exiting.')
+        sys.exit(1)
+
+    # If contribs is 'all', construct the list of all contribs from the contrib native directory
+    # list of directories only
+    if contribs == ['all']:
+        contribs = [d for d in os.listdir(native_dir) if os.path.isdir(os.path.join(native_dir, d))]
+
+    # Clean each contrib
+    for contrib in contribs:
+        print(f'Cleaning contrib: {contrib} for {abi_triplet} in {native_dir}')
+        build_dir = os.path.join(native_dir, contrib, '*')
+        build_stamp = os.path.join(native_dir, f'.{contrib}*')
+        tarball = os.path.join(contrib_dir, 'tarballs', f'{contrib}*.tar.*')
+        bins = os.path.join(contrib_dir, abi_triplet, 'bin', contrib)
+        libs = os.path.join(contrib_dir, abi_triplet, 'lib', f'lib{contrib}*')
+        includes = os.path.join(contrib_dir, abi_triplet, 'include', f'{contrib}*')
+
+        # EXCEPTIONS: pjproject and ffmpeg
+        if contrib == 'pjproject':
+            libs =  f' {os.path.join(contrib_dir, abi_triplet, "lib", "libpj*")}' \
+                    f' {os.path.join(contrib_dir, abi_triplet, "lib", "libsrtp*")}'
+            includes = os.path.join(contrib_dir, abi_triplet, 'include', 'pj*')
+        elif contrib == 'ffmpeg':
+            libs = f' {os.path.join(contrib_dir, abi_triplet, "lib", "libav*")}' \
+                   f' {os.path.join(contrib_dir, abi_triplet, "lib", "libsw*")}'
+            includes = f' {os.path.join(contrib_dir, abi_triplet, "include", "libav*")}' \
+                       f' {os.path.join(contrib_dir, abi_triplet, "include", "libsw*")}'
+
+        # For a dry run:
+        #  execute_script([f'find {build_dir} {build_stamp} {tarball} {bins} {libs} {includes}'], fail=False)
+
+        execute_script([f'rm -rf {build_dir} {build_stamp} {tarball} {bins} {libs} {includes}'], fail=False)
+
+
 def run_run(args):
     run_env = os.environ
 
@@ -625,6 +716,8 @@ def parse_args():
     ap.add_argument('--global-install', default=False, action='store_true')
     ap.add_argument('--debug', default=False, action='store_true',
                     help='Build with debug support; run in GDB')
+    ap.add_argument('--asan', default=False, action='store_true',
+                    help='Build both daemon and client with ASAN')
     ap.add_argument('--background', default=False, action='store_true')
     ap.add_argument('--no-priv-install', dest='priv_install',
                     default=True, action='store_false')
@@ -639,6 +732,12 @@ def parse_args():
                     default=False, action='store_true',
                     help='Do not use Qt WebEngine.')
     ap.add_argument('--arch')
+    ap.add_argument('--clean-contribs', nargs='+',
+                    help='Clean the specified contribs (space separated) or \
+                          "all" to clean all contribs before building.')
+    ap.add_argument('--pywinmake', dest='pywinmake',
+                    default=False, action='store_true',
+                    help='Build Jami for Windows using pywinmake')
 
     dist = choose_distribution()
 
@@ -685,6 +784,10 @@ def choose_distribution():
 def main():
     parsed_args = parse_args()
 
+    # Clean contribs if specified first.
+    if parsed_args.clean_contribs:
+        clean_contribs(parsed_args.clean_contribs)
+
     if parsed_args.dependencies:
         run_dependencies(parsed_args)
 
