@@ -55,16 +55,72 @@ AccountManager::~AccountManager() {
         dht_->join();
 }
 
+void
+AccountManager::onSyncData(DeviceSync&& sync, bool checkDevice)
+{
+    auto sync_date = clock::time_point(clock::duration(sync.date));
+    if (checkDevice) {
+        // If the DHT is used, we need to check the device here
+        if (not info_->contacts->syncDevice(sync.owner->getLongId(), sync_date)) {
+            return;
+        }
+    }
+
+    // Sync known devices
+    JAMI_DEBUG("[Contacts] received device sync data ({:d} devices, {:d} contacts)",
+             sync.devices_known.size() + sync.devices.size(),
+             sync.peers.size());
+    for (const auto& d : sync.devices_known) {
+        findCertificate(d.first, [this, d](const std::shared_ptr<dht::crypto::Certificate>& crt) {
+            if (not crt)
+                return;
+            // std::lock_guard<std::mutex> lock(deviceListMutex_);
+            foundAccountDevice(crt, d.second);
+        });
+    }
+    for (const auto& d : sync.devices) {
+        findCertificate(d.second.sha1,
+                        [this, d](const std::shared_ptr<dht::crypto::Certificate>& crt) {
+                            if (not crt || crt->getLongId() != d.first)
+                                return;
+                            // std::lock_guard<std::mutex> lock(deviceListMutex_);
+                            foundAccountDevice(crt, d.second.name);
+                        });
+    }
+    // saveKnownDevices();
+
+    // Sync contacts
+    for (const auto& peer : sync.peers) {
+        info_->contacts->updateContact(peer.first, peer.second);
+    }
+    info_->contacts->saveContacts();
+
+    // Sync trust requests
+    for (const auto& tr : sync.trust_requests)
+        info_->contacts->onTrustRequest(tr.first,
+                                        tr.second.device,
+                                        tr.second.received,
+                                        false,
+                                        tr.second.conversationId,
+                                        {});
+    info_->contacts->saveTrustRequests();
+}
+
 dht::crypto::Identity
 AccountManager::loadIdentity(const std::string& accountId,
                              const std::string& crt_path,
                              const std::string& key_path,
                              const std::string& key_pwd) const
 {
-    JAMI_DBG("Loading certificate from '%s' and key from '%s' at %s",
-             crt_path.c_str(),
-             key_path.c_str(),
-             path_.c_str());
+    // Return to avoid unnecessary log if certificate or key is missing. Example case: when
+    // importing an account when the certificate has not been unpacked from the archive.
+    if (crt_path.empty() or key_path.empty())
+        return {};
+
+    JAMI_DEBUG("Loading certificate from '{}' and key from '{}' at {}",
+             crt_path,
+             key_path,
+             path_);
     try {
         dht::crypto::Certificate dht_cert(fileutils::loadFile(crt_path, path_));
         dht::crypto::PrivateKey dht_key(fileutils::loadFile(key_path, path_), key_pwd);
@@ -224,7 +280,7 @@ AccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dc
         dht_->put(
             h,
             info_->announce,
-            [this, dcb = std::move(dcb), h](bool ok) {
+            [dcb = std::move(dcb), h](bool ok) {
                 if (ok)
                     JAMI_DEBUG("device announced at {}", h.toString());
                 // We do not care about the status, it's a permanent put, if this fail,
@@ -378,7 +434,7 @@ AccountManager::onPeerMessage(const dht::crypto::PublicKey& peer_device,
 {
     // quick check in case we already explicilty banned this device
     auto trustStatus = getCertificateStatus(peer_device.toString());
-    if (trustStatus == tls::TrustStore::PermissionStatus::BANNED) {
+    if (trustStatus == dhtnet::tls::TrustStore::PermissionStatus::BANNED) {
         JAMI_WARN("[Auth] Discarding message from banned device %s", peer_device.toString().c_str());
         return;
     }
@@ -466,6 +522,28 @@ AccountManager::removeContactConversation(const std::string& uri)
         syncDevices();
 }
 
+void
+AccountManager::updateContactConversation(const std::string& uri, const std::string& convId)
+{
+    dht::InfoHash h(uri);
+    if (not h) {
+        JAMI_ERR("removeContact: invalid contact URI");
+        return;
+    }
+    if (not info_) {
+        JAMI_ERR("addContact(): account not loaded");
+        return;
+    }
+    info_->contacts->updateConversation(h, convId);
+    // Also decline trust request if there is one
+    auto req = info_->contacts->getTrustRequest(h);
+    if (req.find(libjami::Account::TrustRequest::CONVERSATIONID) != req.end()
+        && req.at(libjami::Account::TrustRequest::CONVERSATIONID) == convId) {
+        discardTrustRequest(uri);
+    }
+    syncDevices();
+}
+
 std::vector<std::map<std::string, std::string>>
 AccountManager::getContacts() const
 {
@@ -491,6 +569,10 @@ AccountManager::getContacts() const
 std::map<std::string, std::string>
 AccountManager::getContactDetails(const std::string& uri) const
 {
+    if (!info_) {
+        JAMI_ERR("getContactDetails(): account not loaded");
+        return {};
+    }
     dht::InfoHash h(uri);
     if (not h) {
         JAMI_ERR("getContactDetails: invalid contact URI");
@@ -528,7 +610,8 @@ AccountManager::findCertificate(
     if (auto cert = certStore().getCertificate(id.toString())) {
         if (cb)
             cb(cert);
-    } else if (auto cert = certStore().getCertificateLegacy(id.toString())) {
+    } else if (auto cert = certStore().getCertificateLegacy(fileutils::get_data_dir().string(),
+                                                            id.toString())) {
         if (cb)
             cb(cert);
     } else if (cb)
@@ -538,30 +621,30 @@ AccountManager::findCertificate(
 
 bool
 AccountManager::setCertificateStatus(const std::string& cert_id,
-                                     tls::TrustStore::PermissionStatus status)
+                                     dhtnet::tls::TrustStore::PermissionStatus status)
 {
     return info_ and info_->contacts->setCertificateStatus(cert_id, status);
 }
 
 bool
 AccountManager::setCertificateStatus(const std::shared_ptr<crypto::Certificate>& cert,
-                              tls::TrustStore::PermissionStatus status,
+                              dhtnet::tls::TrustStore::PermissionStatus status,
                               bool local)
 {
     return info_ and info_->contacts->setCertificateStatus(cert, status, local);
 }
 
 std::vector<std::string>
-AccountManager::getCertificatesByStatus(tls::TrustStore::PermissionStatus status)
+AccountManager::getCertificatesByStatus(dhtnet::tls::TrustStore::PermissionStatus status)
 {
     return info_ ? info_->contacts->getCertificatesByStatus(status) : std::vector<std::string> {};
 }
 
-tls::TrustStore::PermissionStatus
+dhtnet::tls::TrustStore::PermissionStatus
 AccountManager::getCertificateStatus(const std::string& cert_id) const
 {
     return info_ ? info_->contacts->getCertificateStatus(cert_id)
-                 : tls::TrustStore::PermissionStatus::UNDEFINED;
+                 : dhtnet::tls::TrustStore::PermissionStatus::UNDEFINED;
 }
 
 bool
@@ -742,7 +825,7 @@ AccountManager::lookupAddress(const std::string& addr, LookupCallback cb)
     nameDir_.get().lookupAddress(addr, cb);
 }
 
-tls::CertificateStore&
+dhtnet::tls::CertificateStore&
 AccountManager::certStore() const
 {
     return Manager::instance().certStore(info_->contacts->accountId());
