@@ -31,6 +31,8 @@
 #include <msgpack.hpp>
 
 namespace jami {
+static constexpr const char MIME_TYPE_INVITE[] {"application/invite"};
+static constexpr const char MIME_TYPE_GIT[] {"application/im-gitmessage-id"};
 
 class SIPCall;
 
@@ -47,13 +49,14 @@ struct SyncMsg
     MSGPACK_DEFINE(ds, c, cr, p, ld)
 };
 
-using ChannelCb = std::function<bool(const std::shared_ptr<ChannelSocket>&)>;
+using ChannelCb = std::function<bool(const std::shared_ptr<dhtnet::ChannelSocket>&)>;
 using NeedSocketCb
     = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
 using SengMsgCb = std::function<
     uint64_t(const std::string&, const DeviceId&, std::map<std::string, std::string>, uint64_t)>;
 using NeedsSyncingCb = std::function<void(std::shared_ptr<SyncMsg>&&)>;
 using UpdateConvReq = std::function<void(const std::string&, const std::string&, bool)>;
+using OneToOneRecvCb = std::function<void(const std::string&, const std::string&)>;
 
 class ConversationModule
 {
@@ -63,7 +66,8 @@ public:
                        SengMsgCb&& sendMsgCb,
                        NeedSocketCb&& onNeedSocket,
                        NeedSocketCb&& onNeedSwarmSocket,
-                       UpdateConvReq&& updateConvReqCb);
+                       UpdateConvReq&& updateConvReqCb,
+                       OneToOneRecvCb&& oneToOneRecvCb);
     ~ConversationModule() = default;
 
     /**
@@ -431,21 +435,20 @@ public:
     // The following methods modify what is stored on the disk
     static void saveConvInfos(const std::string& accountId,
                               const std::map<std::string, ConvInfo>& conversations);
-    static void saveConvInfosToPath(const std::string& path,
+    static void saveConvInfosToPath(const std::filesystem::path& path,
                                     const std::map<std::string, ConvInfo>& conversations);
     static void saveConvRequests(
         const std::string& accountId,
         const std::map<std::string, ConversationRequest>& conversationsRequests);
     static void saveConvRequestsToPath(
-        const std::string& path,
+        const std::filesystem::path& path,
         const std::map<std::string, ConversationRequest>& conversationsRequests);
 
     static std::map<std::string, ConvInfo> convInfos(const std::string& accountId);
-    static std::map<std::string, ConvInfo> convInfosFromPath(const std::string& path);
+    static std::map<std::string, ConvInfo> convInfosFromPath(const std::filesystem::path& path);
     static std::map<std::string, ConversationRequest> convRequests(const std::string& accountId);
-    static std::map<std::string, ConversationRequest> convRequestsFromPath(const std::string& path);
+    static std::map<std::string, ConversationRequest> convRequestsFromPath(const std::filesystem::path& path);
     void addConvInfo(const ConvInfo& info);
-    void setConversationMembers(const std::string& convId, const std::vector<std::string>& members);
 
     /**
      * Get a conversation
@@ -458,12 +461,12 @@ public:
      * @param conversationId    Related conversation
      * @return the related socket
      */
-    std::shared_ptr<ChannelSocket> gitSocket(std::string_view deviceId,
+    std::shared_ptr<dhtnet::ChannelSocket> gitSocket(std::string_view deviceId,
                                              std::string_view convId) const;
     void removeGitSocket(std::string_view deviceId, std::string_view convId);
     void addGitSocket(std::string_view deviceId,
                       std::string_view convId,
-                      const std::shared_ptr<ChannelSocket>& channel);
+                      const std::shared_ptr<dhtnet::ChannelSocket>& channel);
     /**
      * Clear all connection (swarm channels)
      */
@@ -473,7 +476,7 @@ public:
      * @param conversationId
      * @param socket
      */
-    void addSwarmChannel(const std::string& conversationId, std::shared_ptr<ChannelSocket> socket);
+    void addSwarmChannel(const std::string& conversationId, std::shared_ptr<dhtnet::ChannelSocket> socket);
     /**
      * Triggers a bucket maintainance for DRTs
      */
