@@ -74,7 +74,6 @@ using random_device = dht::crypto::random_device;
 #include "client/videomanager.h"
 
 #include "conference.h"
-#include "connectivity/ice_transport.h"
 
 #include "client/ring_signal.h"
 #include "jami/call_const.h"
@@ -92,7 +91,9 @@ using random_device = dht::crypto::random_device;
 #include "data_transfer.h"
 #include "jami/media_const.h"
 
-#include "connectivity/upnp/upnp_context.h"
+#include <dhtnet/ice_transport_factory.h>
+#include <dhtnet/ice_transport.h>
+#include <dhtnet/upnp/upnp_context.h>
 
 #include <libavutil/ffversion.h>
 
@@ -144,10 +145,10 @@ bool Manager::isIOSExtension = {false};
 bool Manager::syncOnRegister = {true};
 
 static void
-copy_over(const std::string& srcPath, const std::string& destPath)
+copy_over(const std::filesystem::path& srcPath, const std::filesystem::path& destPath)
 {
-    std::ifstream src = fileutils::ifstream(srcPath.c_str());
-    std::ofstream dest = fileutils::ofstream(destPath.c_str());
+    std::ifstream src(srcPath);
+    std::ofstream dest(destPath);
     dest << src.rdbuf();
     src.close();
     dest.close();
@@ -155,41 +156,49 @@ copy_over(const std::string& srcPath, const std::string& destPath)
 
 // Creates a backup of the file at "path" with a .bak suffix appended
 static void
-make_backup(const std::string& path)
+make_backup(const std::filesystem::path& path)
 {
-    const std::string backup_path(path + ".bak");
+    auto backup_path = path;
+    backup_path.replace_extension(".bak");
     copy_over(path, backup_path);
 }
 
 // Restore last backup of the configuration file
 static void
-restore_backup(const std::string& path)
+restore_backup(const std::filesystem::path& path)
 {
-    const std::string backup_path(path + ".bak");
+    auto backup_path = path;
+    backup_path.replace_extension(".bak");
     copy_over(backup_path, path);
 }
 
 void
-check_rename(const std::string& old_dir, const std::string& new_dir)
+check_rename(const std::filesystem::path& old_dir, const std::filesystem::path& new_dir)
 {
-    if (old_dir == new_dir or not fileutils::isDirectory(old_dir))
+    if (old_dir == new_dir or not std::filesystem::is_directory(old_dir))
         return;
 
-    if (not fileutils::isDirectory(new_dir)) {
-        JAMI_WARN() << "Migrating " << old_dir << " to " << new_dir;
-        std::rename(old_dir.c_str(), new_dir.c_str());
+    std::error_code ec;
+    if (not std::filesystem::is_directory(new_dir)) {
+        JAMI_WARNING("Migrating {} to {}", old_dir, new_dir);
+        std::filesystem::rename(old_dir, new_dir, ec);
+        if (ec)
+            JAMI_ERROR("Failed to rename {} to {}: {}", old_dir, new_dir, ec.message());
     } else {
-        for (const auto& file : fileutils::readDirectory(old_dir)) {
-            auto old_dest = fileutils::getFullPath(old_dir, file);
-            auto new_dest = fileutils::getFullPath(new_dir, file);
-            if (fileutils::isDirectory(old_dest) and fileutils::isDirectory(new_dest)) {
-                check_rename(old_dest, new_dest);
+        for (const auto& file_iterator : std::filesystem::directory_iterator(old_dir, ec)) {
+            const auto& file_path = file_iterator.path();
+            auto new_path = new_dir / file_path.filename();
+            if (file_iterator.is_directory()
+                and std::filesystem::is_directory(new_path)) {
+                check_rename(file_path, new_path);
             } else {
-                JAMI_WARN() << "Migrating " << old_dest << " to " << new_dest;
-                std::rename(old_dest.c_str(), new_dest.c_str());
+                JAMI_WARNING("Migrating {} to {}", old_dir, new_path);
+                std::filesystem::rename(file_path, new_path, ec);
+                if (ec)
+                    JAMI_ERROR("Failed to rename {} to {}: {}", file_path, new_path, ec.message());
             }
         }
-        fileutils::removeAll(old_dir);
+        std::filesystem::remove_all(old_dir, ec);
     }
 }
 
@@ -207,7 +216,6 @@ static constexpr const char* DHTLOGLEVEL = "DHTLOGLEVEL";
 static void
 setDhtLogLevel()
 {
-#ifndef RING_UWP
     int level = 0;
     if (auto envvar = getenv(DHTLOGLEVEL)) {
         level = to_int<int>(envvar, 0);
@@ -215,9 +223,6 @@ setDhtLogLevel()
         JAMI_DBG("DHTLOGLEVEL=%u", level);
     }
     Manager::instance().dhtLogLevel = level;
-#else
-    Manager::instance().dhtLogLevel = 0;
-#endif
 }
 
 /**
@@ -232,7 +237,6 @@ static constexpr const char* SIPLOGLEVEL = "SIPLOGLEVEL";
 static void
 setSipLogLevel()
 {
-#ifndef RING_UWP
     char* envvar = getenv(SIPLOGLEVEL);
 
     int level = 0;
@@ -243,9 +247,6 @@ setSipLogLevel()
         // From 0 (min) to 6 (max)
         level = std::max(0, std::min(level, 6));
     }
-#else
-    int level = 0;
-#endif
 
     pj_log_set_level(level);
     pj_log_set_log_func([](int level, const char* data, int /*len*/) {
@@ -275,7 +276,6 @@ tls_print_logs(int level, const char* msg)
 static void
 setGnuTlsLogLevel()
 {
-#ifndef RING_UWP
     char* envvar = getenv("RING_TLS_LOGLEVEL");
     int level = RING_TLS_LOGLEVEL;
 
@@ -287,9 +287,6 @@ setGnuTlsLogLevel()
     }
 
     gnutls_global_set_log_level(level);
-#else
-    gnutls_global_set_log_level(RING_TLS_LOGLEVEL);
-#endif
     gnutls_global_set_log_function(tls_print_logs);
 }
 
@@ -320,7 +317,7 @@ struct Manager::ManagerPimpl
     /**
      * Create config directory in home user and return configuration file path
      */
-    std::string retrieveConfigPath() const;
+    std::filesystem::path retrieveConfigPath() const;
 
     void unsetCurrentCall();
 
@@ -363,6 +360,8 @@ struct Manager::ManagerPimpl
     std::shared_ptr<asio::io_context> ioContext_;
     std::thread ioContextRunner_;
 
+    std::shared_ptr<dhtnet::upnp::UPnPContext> upnpContext_;
+
     /** Main scheduler */
     ScheduledExecutor scheduler_ {"manager"};
 
@@ -389,7 +388,7 @@ struct Manager::ManagerPimpl
     std::unique_ptr<DTMF> dtmfKey_;
 
     /** Buffer to generate DTMF */
-    AudioBuffer dtmfBuf_;
+    std::shared_ptr<AudioFrame> dtmfBuf_;
 
     // To handle volume control
     // short speakerVolume_;
@@ -414,7 +413,7 @@ struct Manager::ManagerPimpl
     /**
      * Path of the ConfigFile
      */
-    std::string path_;
+    std::filesystem::path path_;
 
     /**
      * Instance of the RingBufferPool for the whole application
@@ -429,7 +428,7 @@ struct Manager::ManagerPimpl
     std::atomic_bool finished_ {false};
 
     /* ICE support */
-    std::unique_ptr<IceTransportFactory> ice_tf_;
+    std::shared_ptr<dhtnet::IceTransportFactory> ice_tf_;
 
     /* Sink ID mapping */
     std::map<std::string, std::weak_ptr<video::SinkClient>> sinkMap_;
@@ -449,8 +448,9 @@ struct Manager::ManagerPimpl
 Manager::ManagerPimpl::ManagerPimpl(Manager& base)
     : base_(base)
     , ioContext_(std::make_shared<asio::io_context>())
+    , upnpContext_(std::make_shared<dhtnet::upnp::UPnPContext>(nullptr, Logger::dhtLogger()))
     , toneCtrl_(base.preferences)
-    , dtmfBuf_(0, AudioFormat::MONO())
+    , dtmfBuf_(std::make_shared<AudioFrame>())
     , ringbufferpool_(new RingBufferPool)
 #ifdef ENABLE_VIDEO
     , videoManager_(new VideoManager)
@@ -474,7 +474,7 @@ Manager::ManagerPimpl::parseConfiguration()
     bool result = true;
 
     try {
-        std::ifstream file = fileutils::ifstream(path_);
+        std::ifstream file(path_);
         YAML::Node parsedFile = YAML::Load(file);
         file.close();
         const int error_count = base_.loadAccountMap(parsedFile);
@@ -539,8 +539,15 @@ Manager::ManagerPimpl::processRemainingParticipants(Conference& conf)
 
     if (n > 1) {
         // Reset ringbuffer's readpointers
-        for (const auto& p : participants)
-            base_.getRingBufferPool().flush(p);
+        for (const auto& p : participants) {
+            if (auto call = base_.getCallFromCallID(p)) {
+                auto medias = call->getAudioStreams();
+                for (const auto& media : medias) {
+                    JAMI_DEBUG("[call:{}] Remove local audio {}", p, media.first);
+                    base_.getRingBufferPool().flush(media.first);
+                }
+            }
+        }
 
         base_.getRingBufferPool().flush(RingBufferPool::DEFAULT_ID);
     } else if (n == 1) {
@@ -585,11 +592,11 @@ Manager::ManagerPimpl::processRemainingParticipants(Conference& conf)
 /**
  * Initialization: Main Thread
  */
-std::string
+std::filesystem::path
 Manager::ManagerPimpl::retrieveConfigPath() const
 {
     // TODO: Migrate config file name from dring.yml to jami.yml.
-    return fileutils::get_config_dir() + DIR_SEPARATOR_STR + "dring.yml";
+    return fileutils::get_config_dir() / "dring.yml";
 }
 
 void
@@ -670,6 +677,12 @@ Manager::ManagerPimpl::sendTextMessageToConference(const Conference& conf,
     }
 }
 
+void
+Manager::bindCallToConference(Call& call, Conference& conf)
+{
+    pimpl_->bindCallToConference(call, conf);
+}
+
 void
 Manager::ManagerPimpl::bindCallToConference(Call& call, Conference& conf)
 {
@@ -683,7 +696,11 @@ Manager::ManagerPimpl::bindCallToConference(Call& call, Conference& conf)
 
     JAMI_DEBUG("[call:{}] bind to conference {} (callState={})", callId, confId, state);
 
-    base_.getRingBufferPool().unBindAll(callId);
+    auto medias = call.getAudioStreams();
+    for (const auto& media : medias) {
+        JAMI_DEBUG("[call:{}] Remove local audio {}", callId, media.first);
+        base_.getRingBufferPool().unBindAll(media.first);
+    }
 
     conf.addParticipant(callId);
 
@@ -731,8 +748,12 @@ Manager::Manager()
 #endif
     , callFactory(rand_)
     , accountFactory()
-    , pimpl_(new ManagerPimpl(*this))
-{}
+{
+#if defined _MSC_VER
+    gnutls_global_init();
+#endif
+    pimpl_ = std::make_unique<ManagerPimpl>(*this);
+}
 
 Manager::~Manager() {}
 
@@ -743,7 +764,7 @@ Manager::setAutoAnswer(bool enable)
 }
 
 void
-Manager::init(const std::string& config_file, libjami::InitFlag flags)
+Manager::init(const std::filesystem::path& config_file, libjami::InitFlag flags)
 {
     // FIXME: this is no good
     initialized = true;
@@ -755,10 +776,6 @@ Manager::init(const std::string& config_file, libjami::InitFlag flags)
         JAMI_ERR("Unable to initialize git transport %s", error ? error->message : "(unknown)");
     }
 
-#if defined _MSC_VER
-    gnutls_global_init();
-#endif
-
 #ifndef WIN32
     // Set the max number of open files.
     struct rlimit nofiles;
@@ -802,11 +819,13 @@ Manager::init(const std::string& config_file, libjami::InitFlag flags)
     // So only create the SipLink once
     pimpl_->sipLink_ = std::make_unique<SIPVoIPLink>();
 
-    check_rename(fileutils::get_cache_dir(PACKAGE_OLD), fileutils::get_cache_dir());
-    check_rename(fileutils::get_data_dir(PACKAGE_OLD), fileutils::get_data_dir());
-    check_rename(fileutils::get_config_dir(PACKAGE_OLD), fileutils::get_config_dir());
+    check_rename(fileutils::get_cache_dir(PACKAGE_OLD).string(),
+                 fileutils::get_cache_dir().string());
+    check_rename(fileutils::get_data_dir(PACKAGE_OLD).string(), fileutils::get_data_dir().string());
+    check_rename(fileutils::get_config_dir(PACKAGE_OLD).string(),
+                 fileutils::get_config_dir().string());
 
-    pimpl_->ice_tf_.reset(new IceTransportFactory());
+    pimpl_->ice_tf_ = std::make_shared<dhtnet::IceTransportFactory>(Logger::dhtLogger());
 
     pimpl_->path_ = config_file.empty() ? pimpl_->retrieveConfigPath() : config_file;
     JAMI_DBG("Configuration file path: %s", pimpl_->path_.c_str());
@@ -845,8 +864,11 @@ Manager::init(const std::string& config_file, libjami::InitFlag flags)
         std::lock_guard<std::mutex> lock(pimpl_->audioLayerMutex_);
         pimpl_->initAudioDriver();
         if (pimpl_->audiodriver_) {
-            pimpl_->toneCtrl_.setSampleRate(pimpl_->audiodriver_->getSampleRate());
-            pimpl_->dtmfKey_.reset(new DTMF(getRingBufferPool().getInternalSamplingRate()));
+            auto format = pimpl_->audiodriver_->getFormat();
+            pimpl_->toneCtrl_.setSampleRate(format.sample_rate, format.sampleFormat);
+            pimpl_->dtmfKey_.reset(
+                new DTMF(getRingBufferPool().getInternalSamplingRate(),
+                         getRingBufferPool().getInternalAudioFormat().sampleFormat));
         }
     }
     registerAccounts();
@@ -861,7 +883,7 @@ Manager::finish() noexcept
 
     try {
         // Terminate UPNP context
-        jami::upnp::UPnPContext::getUPnPContext()->shutdown();
+        upnpContext()->shutdown();
 
         // Forbid call creation
         callFactory.forbid();
@@ -940,7 +962,8 @@ Manager::monitor(bool continuous)
 #ifdef __linux__
 #if defined(__ANDROID__)
 #else
-    auto opened_files = fileutils::readDirectory("/proc/" + std::to_string(getpid()) + "/fd").size();
+    auto opened_files
+        = dhtnet::fileutils::readDirectory("/proc/" + std::to_string(getpid()) + "/fd").size();
     JAMI_DBG("Opened files: %lu", opened_files);
 #endif
 #endif
@@ -954,6 +977,67 @@ Manager::monitor(bool continuous)
     Logger::setMonitorLog(continuous);
 }
 
+std::vector<std::map<std::string, std::string>>
+Manager::getConnectionList(const std::string& accountId, const std::string& conversationId)
+{
+    std::vector<std::map<std::string, std::string>> connectionsList;
+
+    if (accountId.empty()) {
+        for (const auto& account : getAllAccounts<JamiAccount>()) {
+            if (account->getRegistrationState() != RegistrationState::INITIALIZING) {
+                const auto& cnl = account->getConnectionList(conversationId);
+                connectionsList.insert(connectionsList.end(), cnl.begin(), cnl.end());
+            }
+        }
+    } else {
+        auto account = getAccount(accountId);
+        if (account) {
+            if (auto acc = std::dynamic_pointer_cast<JamiAccount>(account)) {
+                if (acc->getRegistrationState() != RegistrationState::INITIALIZING) {
+                    const auto& cnl = acc->getConnectionList(conversationId);
+                    connectionsList.insert(connectionsList.end(), cnl.begin(), cnl.end());
+                }
+            }
+        }
+    }
+
+    return connectionsList;
+}
+
+std::vector<std::map<std::string, std::string>>
+Manager::getChannelList(const std::string& accountId, const std::string& connectionId)
+{
+    // if account id is empty, return all channels
+    // else return only for specific accountid
+    std::vector<std::map<std::string, std::string>> channelsList;
+
+    if (accountId.empty()) {
+        for (const auto& account : getAllAccounts<JamiAccount>()) {
+            if (account->getRegistrationState() != RegistrationState::INITIALIZING) {
+                // add to channelsList all channels for this account
+                const auto& cnl = account->getChannelList(connectionId);
+                channelsList.insert(channelsList.end(), cnl.begin(), cnl.end());
+            }
+        }
+
+    }
+
+    else {
+        // get the jamiaccount for this accountid and return its channels
+        auto account = getAccount(accountId);
+        if (account) {
+            if (auto acc = std::dynamic_pointer_cast<JamiAccount>(account)) {
+                if (acc->getRegistrationState() != RegistrationState::INITIALIZING) {
+                    const auto& cnl = acc->getChannelList(connectionId);
+                    channelsList.insert(channelsList.end(), cnl.begin(), cnl.end());
+                }
+            }
+        }
+    }
+
+    return channelsList;
+}
+
 bool
 Manager::isCurrentCall(const Call& call) const
 {
@@ -1213,11 +1297,8 @@ Manager::transferCall(const std::string& accountId, const std::string& callId, c
     if (not account)
         return false;
     if (auto call = account->getCall(callId)) {
-        if (call->isConferenceParticipant()) {
+        if (call->isConferenceParticipant())
             removeParticipant(*call);
-        } /*else if (not isConference(getCurrentCallId())) {
-            pimpl_->unsetCurrentCall();
-        }*/
         call->transfer(to);
     } else
         return false;
@@ -1323,22 +1404,17 @@ Manager::addParticipant(const std::string& accountId,
 bool
 Manager::addParticipant(Call& call, Conference& conference)
 {
-    // No-op if the call is already a conference participant
-    /*if (call.getConfId() == conference.getConfId()) {
-        JAMI_WARN("Call %s already participant of conf %s", call.getCallId().c_str(),
-    conference.getConfId().c_str()); return true;
-    }*/
-
-    JAMI_DBG("Add participant %s to conference %s",
-             call.getCallId().c_str(),
-             conference.getConfId().c_str());
+    JAMI_DEBUG("Add participant {} to conference {}",
+             call.getCallId(),
+             conference.getConfId());
 
     // store the current call id (it will change in offHoldCall or in answerCall)
     pimpl_->bindCallToConference(call, conference);
 
     // Don't attach current user yet
-    if (conference.getState() == Conference::State::ACTIVE_DETACHED)
+    if (conference.getState() == Conference::State::ACTIVE_DETACHED) {
         return true;
+    }
 
     // TODO: remove this ugly hack => There should be different calls when double clicking
     // a conference to add main participant to it, or (in this case) adding a participant
@@ -1434,7 +1510,10 @@ Manager::joinParticipant(const std::string& accountId,
         return false;
     }
 
-    auto conf = std::make_shared<Conference>(account);
+    auto mediaAttr = call1->getMediaAttributeList();
+    if (mediaAttr.empty())
+        mediaAttr = call2->getMediaAttributeList();
+    auto conf = std::make_shared<Conference>(account, "", true, mediaAttr);
     account->attach(conf);
     emitSignal<libjami::CallSignal::ConferenceCreated>(account->getAccountID(), conf->getConfId());
 
@@ -1613,10 +1692,10 @@ void
 Manager::addAudio(Call& call)
 {
     const auto& callId = call.getCallId();
-    JAMI_INFO("Add audio to call %s", callId.c_str());
+    JAMI_LOG("Add audio to call {}", callId);
 
     if (call.isConferenceParticipant()) {
-        JAMI_DBG("[conf:%s] Attach local audio", callId.c_str());
+        JAMI_DEBUG("[conf:{}] Attach local audio", callId);
 
         // bind to conference participant
         /*auto iter = pimpl_->conferenceMap_.find(callId);
@@ -1624,16 +1703,21 @@ Manager::addAudio(Call& call)
             iter->second->bindParticipant(callId);
         }*/
     } else {
-        JAMI_DBG("[call:%s] Attach audio", callId.c_str());
+        JAMI_DEBUG("[call:{}] Attach audio", callId);
 
         // bind to main
-        getRingBufferPool().bindCallID(callId, RingBufferPool::DEFAULT_ID);
+        auto medias = call.getAudioStreams();
+        for (const auto& media : medias) {
+            JAMI_DEBUG("[call:{}] Attach audio", media.first);
+            getRingBufferPool().bindRingbuffers(media.first,
+                                            RingBufferPool::DEFAULT_ID);
+        }
         auto oldGuard = std::move(call.audioGuard);
         call.audioGuard = startAudioStream(AudioDeviceType::PLAYBACK);
 
         std::lock_guard<std::mutex> lock(pimpl_->audioLayerMutex_);
         if (!pimpl_->audiodriver_) {
-            JAMI_ERR("Audio driver not initialized");
+            JAMI_ERROR("Audio driver not initialized");
             return;
         }
         pimpl_->audiodriver_->flushUrgent();
@@ -1645,9 +1729,11 @@ void
 Manager::removeAudio(Call& call)
 {
     const auto& callId = call.getCallId();
-    JAMI_DBG("[call:%s] Remove local audio", callId.c_str());
-    getRingBufferPool().unBindAll(callId);
-    call.audioGuard.reset();
+    auto medias = call.getAudioStreams();
+    for (const auto& media : medias) {
+        JAMI_DEBUG("[call:{}] Remove local audio {}", callId, media.first);
+        getRingBufferPool().unBindAll(media.first);
+    }
 }
 
 ScheduledExecutor&
@@ -1662,6 +1748,12 @@ Manager::ioContext() const
     return pimpl_->ioContext_;
 }
 
+std::shared_ptr<dhtnet::upnp::UPnPContext>
+Manager::upnpContext() const
+{
+    return pimpl_->upnpContext_;
+}
+
 std::shared_ptr<Task>
 Manager::scheduleTask(std::function<void()>&& task,
                       std::chrono::steady_clock::time_point when,
@@ -1709,10 +1801,10 @@ Manager::saveConfig()
         out << YAML::Value << YAML::BeginSeq;
 
         for (const auto& account : accountFactory.getAllAccounts()) {
-            if (auto ringAccount = std::dynamic_pointer_cast<JamiAccount>(account)) {
-                auto accountConfig = ringAccount->getPath() + DIR_SEPARATOR_STR + "config.yml";
-                if (not fileutils::isFile(accountConfig)) {
-                    saveConfig(ringAccount);
+            if (auto jamiAccount = std::dynamic_pointer_cast<JamiAccount>(account)) {
+                auto accountConfig = jamiAccount->getPath() / "config.yml";
+                if (not std::filesystem::is_regular_file(accountConfig)) {
+                    saveConfig(jamiAccount);
                 }
             } else {
                 account->config().serialize(out);
@@ -1732,8 +1824,8 @@ Manager::saveConfig()
         pluginPreferences.serialize(out);
 #endif
 
-        std::lock_guard<std::mutex> lock(fileutils::getFileLock(pimpl_->path_));
-        std::ofstream fout = fileutils::ofstream(pimpl_->path_);
+        std::lock_guard<std::mutex> lock(dhtnet::fileutils::getFileLock(pimpl_->path_));
+        std::ofstream fout(pimpl_->path_);
         fout.write(out.c_str(), out.size());
     } catch (const YAML::Exception& e) {
         JAMI_ERR("%s", e.what());
@@ -1779,14 +1871,15 @@ Manager::playDtmf(char code)
     // size (n sampling) = time_ms * sampling/s
     //                     ---------------------
     //                            ms/s
-    int size = (int) ((pulselen * (float) pimpl_->audiodriver_->getSampleRate()) / 1000);
-    pimpl_->dtmfBuf_.resize(size);
+    unsigned size = (unsigned) ((pulselen * (long) pimpl_->audiodriver_->getSampleRate()) / 1000ul);
+    if (!pimpl_->dtmfBuf_ or pimpl_->dtmfBuf_->getFrameSize() != size)
+        pimpl_->dtmfBuf_ = std::make_shared<AudioFrame>(pimpl_->audiodriver_->getFormat(), size);
 
     // Handle dtmf
     pimpl_->dtmfKey_->startTone(code);
 
     // copy the sound
-    if (pimpl_->dtmfKey_->generateDTMF(*pimpl_->dtmfBuf_.getChannel(0))) {
+    if (pimpl_->dtmfKey_->generateDTMF(pimpl_->dtmfBuf_->pointer())) {
         // Put buffer to urgentRingBuffer
         // put the size in bytes...
         // so size * 1 channel (mono) * sizeof (bytes for the data)
@@ -2000,7 +2093,7 @@ Manager::callFailure(Call& call)
     }
 
     pimpl_->removeWaitingCall(call.getCallId());
-    if (not incomingCallsWaiting())
+    if (not call.isSubcall() && not incomingCallsWaiting())
         stopTone();
     removeAudio(call);
 }
@@ -2081,10 +2174,11 @@ Manager::playRingtone(const std::string& accountID)
         // start audio if not started AND flush all buffers (main and urgent)
         auto oldGuard = std::move(pimpl_->toneDeviceGuard_);
         pimpl_->toneDeviceGuard_ = startAudioStream(AudioDeviceType::RINGTONE);
-        pimpl_->toneCtrl_.setSampleRate(pimpl_->audiodriver_->getSampleRate());
+        auto format = pimpl_->audiodriver_->getFormat();
+        pimpl_->toneCtrl_.setSampleRate(format.sample_rate, format.sampleFormat);
     }
 
-    if (not pimpl_->toneCtrl_.setAudioFile(account->getRingtonePath()))
+    if (not pimpl_->toneCtrl_.setAudioFile(account->getRingtonePath().string()))
         ringback();
 }
 
@@ -2276,7 +2370,8 @@ Manager::startRecordedFilePlayback(const std::string& filepath)
 
         auto oldGuard = std::move(pimpl_->toneDeviceGuard_);
         pimpl_->toneDeviceGuard_ = startAudioStream(AudioDeviceType::RINGTONE);
-        pimpl_->toneCtrl_.setSampleRate(pimpl_->audiodriver_->getSampleRate());
+        auto format = pimpl_->audiodriver_->getFormat();
+        pimpl_->toneCtrl_.setSampleRate(format.sample_rate, format.sampleFormat);
     }
 
     return pimpl_->toneCtrl_.setAudioFile(filepath);
@@ -2475,11 +2570,11 @@ Manager::ManagerPimpl::processIncomingCall(const std::string& accountId, Call& i
         incomCall.getMediaAttributeList());
 
     if (mediaList.empty())
-        JAMI_WARN("Incoming call %s has an empty media list", incomCallId.c_str());
+        JAMI_WARNING("Incoming call {} has an empty media list", incomCallId);
 
-    JAMI_INFO("Incoming call %s on account %s with %lu media",
-              incomCallId.c_str(),
-              accountId.c_str(),
+    JAMI_DEBUG("Incoming call {} on account {} with {} media",
+              incomCallId,
+              accountId,
               mediaList.size());
 
     emitSignal<libjami::CallSignal::IncomingCallWithMedia>(accountId,
@@ -2489,7 +2584,7 @@ Manager::ManagerPimpl::processIncomingCall(const std::string& accountId, Call& i
 
     if (not base_.hasCurrentCall()) {
         incomCall.setState(Call::ConnectionState::RINGING);
-#if !defined(RING_UWP) && !(defined(TARGET_OS_IOS) && TARGET_OS_IOS)
+#if !(defined(TARGET_OS_IOS) && TARGET_OS_IOS)
         if (not account->isRendezVous())
             base_.playRingtone(accountId);
 #endif
@@ -2583,13 +2678,11 @@ Manager::audioFormatUsed(AudioFormat format)
     if (currentFormat == format)
         return format;
 
-    JAMI_DBG("Audio format changed: %s -> %s",
-             currentFormat.toString().c_str(),
-             format.toString().c_str());
+    JAMI_DEBUG("Audio format changed: {} -> {}", currentFormat.toString(), format.toString());
 
     pimpl_->ringbufferpool_->setInternalAudioFormat(format);
-    pimpl_->toneCtrl_.setSampleRate(format.sample_rate);
-    pimpl_->dtmfKey_.reset(new DTMF(format.sample_rate));
+    pimpl_->toneCtrl_.setSampleRate(format.sample_rate, format.sampleFormat);
+    pimpl_->dtmfKey_.reset(new DTMF(format.sample_rate, format.sampleFormat));
 
     return format;
 }
@@ -2630,7 +2723,7 @@ Manager::getAccountDetails(const std::string& accountID) const
     } else {
         JAMI_ERR("Could not get account details on a non-existing accountID %s", accountID.c_str());
         // return an empty map since we can't throw an exception to D-Bus
-        return std::map<std::string, std::string>();
+        return {};
     }
 }
 
@@ -2797,7 +2890,7 @@ Manager::loadAccountMap(const YAML::Node& node)
     }
 
     auto accountBaseDir = fileutils::get_data_dir();
-    auto dirs = fileutils::readDirectory(accountBaseDir);
+    auto dirs = dhtnet::fileutils::readDirectory(accountBaseDir);
 
     std::condition_variable cv;
     std::mutex lock;
@@ -2808,29 +2901,24 @@ Manager::loadAccountMap(const YAML::Node& node)
             continue;
         }
         remaining++;
-        dht::ThreadPool::computation().run([this,
-                                            dir,
-                                            &cv,
-                                            &remaining,
-                                            &lock,
-                                            configFile = accountBaseDir + DIR_SEPARATOR_STR + dir
-                                                         + DIR_SEPARATOR_STR + "config.yml"] {
-            if (fileutils::isFile(configFile)) {
-                try {
-                    auto configNode = YAML::LoadFile(configFile);
-                    if (auto a = accountFactory.createAccount(JamiAccount::ACCOUNT_TYPE, dir)) {
-                        auto config = a->buildConfig();
-                        config->unserialize(configNode);
-                        a->setConfig(std::move(config));
+        dht::ThreadPool::computation().run(
+            [this, dir, &cv, &remaining, &lock, configFile = accountBaseDir / dir / "config.yml"] {
+                if (std::filesystem::is_regular_file(configFile)) {
+                    try {
+                        auto configNode = YAML::LoadFile(configFile.string());
+                        if (auto a = accountFactory.createAccount(JamiAccount::ACCOUNT_TYPE, dir)) {
+                            auto config = a->buildConfig();
+                            config->unserialize(configNode);
+                            a->setConfig(std::move(config));
+                        }
+                    } catch (const std::exception& e) {
+                        JAMI_ERR("Can't import account %s: %s", dir.c_str(), e.what());
                     }
-                } catch (const std::exception& e) {
-                    JAMI_ERR("Can't import account %s: %s", dir.c_str(), e.what());
                 }
-            }
-            std::lock_guard<std::mutex> l(lock);
-            remaining--;
-            cv.notify_one();
-        });
+                std::lock_guard<std::mutex> l(lock);
+                remaining--;
+                cv.notify_one();
+            });
     }
     cv.wait(l, [&remaining] { return remaining == 0; });
 
@@ -3110,10 +3198,10 @@ Manager::hasAccount(const std::string& accountID)
     return accountFactory.hasAccount(accountID);
 }
 
-IceTransportFactory&
+const std::shared_ptr<dhtnet::IceTransportFactory>&
 Manager::getIceTransportFactory()
 {
-    return *pimpl_->ice_tf_;
+    return pimpl_->ice_tf_;
 }
 
 VideoManager&
@@ -3144,7 +3232,7 @@ Manager::getJamiPluginManager() const
 }
 #endif
 
-std::shared_ptr<ChannelSocket>
+std::shared_ptr<dhtnet::ChannelSocket>
 Manager::gitSocket(std::string_view accountId,
                    std::string_view deviceId,
                    std::string_view conversationId)
@@ -3243,7 +3331,7 @@ Manager::eraseGitTransport(git_smart_subtransport* tr)
     pimpl_->gitTransports_.erase(tr);
 }
 
-tls::CertificateStore&
+dhtnet::tls::CertificateStore&
 Manager::certStore(const std::string& accountId) const
 {
     if (const auto& account = getAccount<JamiAccount>(accountId)) {
