@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-
+# -*- coding: utf-8 -*-
 """
 Build, test, and package the project.
 
@@ -65,6 +65,15 @@ this_dir = os.path.dirname(os.path.realpath(__file__))
 repo_root_dir = os.path.abspath(os.path.join(this_dir, os.pardir, os.pardir))
 build_dir = os.path.join(repo_root_dir, "build")
 
+def get_latest_toolset_version():
+    """Get the latest toolset version."""
+    # Get the visual studio version. Use only the major version number.
+    # Then: toolset = 2022 ? "v143" : 2019 ? "v142" : 2017 ? "v141" : "v140"
+    vs_ver = get_vs_prop("installationVersion")
+    if vs_ver is None:
+        return None
+    vs_ver = int(vs_ver.split(".")[0])
+    return "v143" if vs_ver >= 16 else "v142" if vs_ver >= 15 else "v141"
 
 def find_latest_qt_path():
     """Find the latest Qt installation path."""
@@ -190,40 +199,31 @@ def init_submodules():
     """Initialize any git submodules in the project."""
     print("Initializing submodules...")
 
-    if execute_cmd(["git", "submodule", "update", "--init"], False):
+    # Init the client submodules for Windows other than the daemon.
+    submodules = [
+        "3rdparty/qrencode-win32",
+        "3rdparty/SortFilterProxyModel",
+        "3rdparty/md4c",
+        "3rdparty/tidy-html5",
+    ]
+    if execute_cmd(["git", "submodule", "update", "--init" ] + submodules,
+                   False):
         print("Submodule initialization error.")
-    else:
-        if execute_cmd(["git", "submodule", "update", "--recursive"], False):
-            print("Submodule recursive checkout error.")
-        else:
-            print("Submodule recursive checkout finished.")
+        sys.exit(1)
 
 
 def build_deps():
     """Build the dependencies for the project."""
-    print('Patching and building qrencode')
-    apply_cmd = [
-        'git',
-        'apply',
-        '--reject',
-        '--ignore-whitespace',
-        '--whitespace=fix'
-    ]
+    print('Building qrencode')
     qrencode_dir = os.path.join(repo_root_dir, '3rdparty', 'qrencode-win32')
-    patch_file = os.path.join(repo_root_dir, 'qrencode-win32.patch')
-    apply_cmd.append(patch_file)
-    if execute_cmd(apply_cmd, False, None, qrencode_dir):
-        print("Couldn't patch qrencode-win32.")
-
     vs_env_vars = {}
     vs_env_vars.update(get_vs_env())
-
-    msbuild_args = get_ms_build_args("x64", "Release-Lib")
-
+    toolset = get_latest_toolset_version()
+    print(f'Using toolset {toolset}')
+    msbuild_args = get_ms_build_args("x64", "Release-Lib", toolset)
     proj_path = os.path.join(
-        qrencode_dir, "qrencode-win32", "vc8", "qrcodelib", "qrcodelib.vcxproj"
+        qrencode_dir, "qrencode-win32", "vc15", "qrcodelib", "qrcodelib.vcxproj"
     )
-
     build_project(msbuild_args, proj_path, vs_env_vars)
 
 
@@ -264,17 +264,15 @@ def build(config_str, qt_dir, tests):
 
     # Get the daemon bin/include directories.
     daemon_dir = os.path.join(repo_root_dir, "daemon")
-    daemon_bin_dir = os.path.join(
-        daemon_dir, "build", "x64", "ReleaseLib_win32", "bin")
+    daemon_bin_dir = os.path.join(daemon_dir, "build", "lib")
 
     # We need to update the minimum SDK version to be able to
     # build with system theme support
     cmake_options = [
-        "-DWITH_DAEMON_SUBMODULE=ON",
+        "-DJAMICORE_AS_SUBDIR=ON",
         "-DCMAKE_PREFIX_PATH=" + qt_dir,
         "-DCMAKE_MSVCIDE_RUN_PATH=" + qt_dir + "\\bin",
-        "-DCMAKE_INSTALL_PREFIX=" + daemon_bin_dir,
-        "-DLIBJAMI_INCLUDE_DIR=" + daemon_dir + "\\src\\jami",
+        "-DCMAKE_INSTALL_PREFIX=" + os.getcwd(),
         "-DCMAKE_SYSTEM_VERSION=" + WIN_SDK_VERSION,
         "-DCMAKE_BUILD_TYPE=" + "Release",
         "-DENABLE_TESTS=" + str(tests).lower(),
