@@ -105,7 +105,8 @@ ScreenInfo::onPhysicalDotsPerInchChanged()
 }
 
 MainApplication::MainApplication(int& argc, char** argv)
-    : QApplication(argc, argv), isCleanupped(false)
+    : QApplication(argc, argv)
+    , isCleanupped(false)
 {
     const char* qtVersion = qVersion();
     qInfo() << "Using Qt runtime version:" << qtVersion;
@@ -196,6 +197,12 @@ MainApplication::init()
     engine_.get()->rootContext()->setContextProperty("WITH_WEBENGINE", QVariant(false));
 #endif
 
+#ifdef APPSTORE
+    engine_.get()->rootContext()->setContextProperty("APPSTORE", QVariant(true));
+#else
+    engine_.get()->rootContext()->setContextProperty("APPSTORE", QVariant(false));
+#endif
+
     initQmlLayer();
 
     settingsManager_->setValue(Settings::Key::StartMinimized,
